---
title: "Half a Year Later: Why I Switched From iOS to GrapheneOS"
date: 2023-01-11T00:00:25-07:00
draft: false
---
It has now been about a half-year [since I abandoned Apple's ship](/blog/ditched-iphone) in favor of joining the ranks of open source tenderness with GrapheneOS on a Pixel 5a, and I have learned a **lot**, to say the least. I have been put in some weird situations about what I really want in my digital life and what sacrifices I would have to make in order to either make my life a little easier and in control, but I am happy to report that I feel comfortable with my decisions and am working to do even better. This article isn't a full list of what I went through these last few months in this experiment (mostly because I forget), but I will do my best to summarize all the thoughts I had and the changes I made to make my digital life more secure and private into this article.

Before I begin, I would like to preface that all of the following information reflects *my* privacy/security threat model. If you are also looking to start your journey down the privacy brick road, I would suggest that you do your own research about privacy issues and see what you would like to protect yourself from. I would also like to clarify now: make sure you understand the difference between privacy and security. This was something I failed to understand before starting on my journey, and it could just be common sense, but make sure you know what you would like to prioritize in your threat model. 

## Apps and Services

I am happy to say that over 60% of all the apps and services I use are open-source and/or privacy respecting! Some changes I made immediately after I got my Pixel, and some I literally made last week. It has taken a lot of effort to try and find alternatives to the things I use daily, or find ways to self-host certain things. However, there are a couple spyware services that I still need to use, such as Zoom for my job and Canvas for school, but I feel that one step at a time will always make a big difference.

Here is a small list of the changes I made since I first got my phone:
* Github -> [Codeberg](https://codeberg.org/brysonsteck)
    * I use [GitNex](https://codeberg.org/gitnex/GitNex) to work with my Codeberg repos on my phone.
* Gmail[^1] -> Proton Mail -> Self Hosted Email ([thanks Luke!](https://github.com/lukesmithxyz/emailwiz))
    * I use [K9 Mail](https://github.com/thundernest/k-9) to manage my email on my phone
* Plex Server -> [Jellyfin](https://jellyfin.org/)
* Apple Notes -> [Joplin](https://joplinapp.org/)
* FaceTime -> [Signal](https://www.signal.org/)
* Made-up passwords -> [KeePassXC](https://keepassxc.org/)

Here are some services that I'm still using but actively seeking alternatives for:
* Spotify
    * I have experimented with using my Jellyfin server, but I will have to sit down and get all my music onto it, which is incredibly time consuming with my current process.
* SMS/MMS
    * *Literally everyone* I know uses it, mainly because [Apple likes their walled garden,](https://www.android.com/get-the-message/) and it's one of the most insecure protocols used nowadays. 
    * I have been using Signal for getting sensitive photos and information between me and people I care about, but they don't understand it or why it matters to use the app. Hopefully over time it will become more common.
* Discord
    * The [Fosscord project](https://fosscord.com/) looks really interesting. I'm waiting to see where that goes, but for now it's the only way people I know wish to communicate.

I have experimented with using open-source alternatives for these services. I especially use [`spotify-tui`](https://github.com/Rigellute/spotify-tui) for Spotify on my laptop, but these don't do much to protect privacy, especially because you must have an account and/or be paying in order for these clients to even work.

As for the other Big Brother services I still use, I don't need them and it would be best to delete those accounts, but it's now at the point for most of them where I'm either second guessing the decisions I made to become more private online or playing the "what if?" game. That is the price you pay when gambling with becoming more private online though, and it's something you have to reiterate to your mind in order to convince yourself.

## My Phone and GrapheneOS

[GrapheneOS](https://grapheneos.org/) has been absolutely fantastic, and I recommend this to anyone looking to de-Google their Google Pixel or switch from an iPhone. It gives you a bunch of security enhancements that the AOSP[^2] does not have by default, including managing network and sensor permissions and secure app spawning, as well as a large amount of privacy with Google Play Services uninstalled by default. If you do choose to install them, they are sandboxed and you can control what permissions are given to them unlike all other Android devices. I found that they install the microG implementations of the Services, but that could also be a bug making that show up in my F-Droid client. 

Any issues that I have had with GrapheneOS have almost always been issues that were pulled in from the AOSP and therefore unrelated to the OS. I have some issues where app-switching causes weird visual and functional issues, but I've heard from other Pixel 5a owners that they experience the same thing with the stock Google-ized OS. 

As per the Google Pixel 5a that it runs on, I actually kind of swung back and forth between one of two different thoughts, more-so the first:
1. I feel like I should have gotten the Pixel 6 or Pixel 6 Pro (the newest Pixels at the time) because I need the extra punch in the random moments where performance matters.
1. I don't need the extra punch, it doesn't stop me from doing the things I need to use it for.

However, at this half-year mark, I decided that what I have now is decent for what I need it for. If people complain about it being too slow, then I believe there's better things they should be prioritizing when it comes to how they use their devices.

## Where Do I Go from Here?
As I admitted earlier, I still have one leg hanging off the ledge, but I do my best to either mitigate the services and apps that I can't completely avoid at the moment or protect myself as best as possible when using the said platforms. As Drew DeVault wisely put it, [privacy is a hobby.](https://drewdevault.com/2016/06/29/Privacy-as-a-hobby.html) While I wouldn't consider my practices to be perfect the last year, neither would the first 5 scarfs you crocheted. You never get things perfect the first time around, and practice makes perfect.

I have thought about creating a new page on my website that tracks my progress on all the services I use and tracking my progress to being as private as I can in this surveillance cesspool. While that may expose my internet activity online, I think it may help those who don't know where to start and give them suggestions on alternatives.

If you too have been looking for a way out of Apple's ecosystem, I say get a Pixel phone with GrapheneOS. If you just jump ship like I did and research open-source alternatives beforehand, you will go down one of the few rabbit holes that actually has benefits for you!

[^1]: I still have Gmail unfortunately, it's a point of contact for several important people in my life still. I have been working on a plan on how to phase it out though, especially since less people start sending me emails since December and I get more spam. I have completely phased out using the Gmail web client though!
[^2]: Acronym for "Android Open Source Project", of which GrapheneOS is a fork of.

